@@ -21,6 +21,13 @@ class UICaptchaNotSolved(Exception):
 
     pass
 
+class ImageCaptchaNotSolved(Exception):
+    """
+    UI: Cannot find image source for solve captcha
+    """
+
+    pass
+
 
 class ParamsException(Exception):
     """
